@@ -28,10 +28,10 @@ typedef struct _ThemeCallbackData
 } ThemeCallbackData;
 
 
-GHashTable *theme_hash = NULL;
-GHashTable *icon_theme_hash = NULL;
-GHashTable *meta_theme_hash = NULL;
-GList *callbacks = NULL;
+static GHashTable *theme_hash = NULL;
+static GHashTable *icon_theme_hash = NULL;
+static GHashTable *meta_theme_hash = NULL;
+static GList *callbacks = NULL;
 
 
 const gchar *gtk2_suffix = "gtk-2.0";
@@ -210,6 +210,7 @@ update_theme_dir (const gchar *theme_dir)
     {
       GList *list;
 
+      g_print ("changed!\n");
       for (list = callbacks; list; list = list->next)
 	{
 	  ThemeCallbackData *callback_data = list->data;
@@ -217,6 +218,10 @@ update_theme_dir (const gchar *theme_dir)
 	  (* callback_data->func) ((gpointer)theme_dir, callback_data->data);
 	}
     }
+  else
+    {
+      g_print ("no change!\n");
+    }
 
 }
 
@@ -262,7 +267,11 @@ top_theme_dir_changed_callback (GnomeVFSMonitorHandle    *handle,
 				GnomeVFSMonitorEventType  event_type,
 				gpointer                  user_data)
 {
-  GFreeFunc *func = user_data;
+  typedef void (*ThemeChangedFunc) (const gchar *uri);
+  ThemeChangedFunc func;
+  
+
+  func = user_data;
 
   switch (event_type)
     {
@@ -270,9 +279,13 @@ top_theme_dir_changed_callback (GnomeVFSMonitorHandle    *handle,
     case GNOME_VFS_MONITOR_EVENT_CREATED:
     case GNOME_VFS_MONITOR_EVENT_DELETED:
       if (!strncmp (info_uri, "file://", strlen ("file://")))
-	(*func) ((char *)info_uri + strlen ("file://"));
+	{
+	  func (info_uri + strlen ("file://"));
+	}
       else
-	(*func) ((char *)info_uri);
+	{
+	  func (info_uri);
+	}
       break;
     default:
       break;
