@@ -236,7 +236,8 @@ sound_view_init (GtkObject *object)
 
 	frame = gtk_frame_new ("");
 	label = gtk_label_new_with_mnemonic (_("_Sounds"));
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label),
+				       GTK_WIDGET (view->priv->view));
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_container_add (GTK_CONTAINER (frame), widget);
 
@@ -325,11 +326,17 @@ foreach_cb (gchar *category, gchar *desc, GList *events, SoundView *view)
 		return;
 
 	gtk_tree_store_append (GTK_TREE_STORE (view->priv->model), &iter, NULL);
-	/* IMHO " " is always first in sort */
+	/* Force the gnome-2 items to the begining of the list by lying about
+	 * its description in the sort key
+	 * 
+	 * http://bugzilla.gnome.org/show_bug.cgi?id=76437
+	 * disable this until we know why this doesn't work.
+	 * I do not feel like wasting time figuring it out
+	 */
 	gtk_tree_store_set (GTK_TREE_STORE (view->priv->model), &iter,
 			    EVENT_COLUMN, desc,
 			    FILE_COLUMN, NULL,
-			    SORT_DATA_COLUMN, (!g_ascii_strcasecmp (category, "gnome-2")) ? " " : desc,
+			    SORT_DATA_COLUMN, "Why the hell doesn't this work", /* (!g_ascii_strcasecmp (category, "gnome-2")) ? " " : desc, */
 			    TYPE_COLUMN, (guint) CATEGORY,
 			    DATA_COLUMN, category,
 			    -1);
